@@ -1,7 +1,3 @@
-#' @importFrom bayestestR equivalence_test
-#' @export
-bayestestR::equivalence_test
-
 #' @title Test for Practical Equivalence
 #'
 #' @description Perform a **Test for Practical Equivalence** for indices of
@@ -140,7 +136,7 @@ equivalence_test.effectsize_table <- function(x,
 
   # x$ROPE_Equivalence[x$CI_low == x$CI_high] <- NA_character_
 
-  class(x) <- c("equivalence_test_effectsize", "see_equivalence_test_effectsize", "data.frame")
+  class(x) <- c("equivalence_test_effectsize", "effectsize_table", "see_equivalence_test_effectsize", "data.frame")
   attr(x, "rope") <- range
   attr(x, "rule") <- rule
   return(x)
