@@ -19,7 +19,7 @@ eta_squared_posterior <- function(model,
 
 #' @export
 #' @importFrom stats lm setNames
-#' @importFrom insight model_info find_formula get_predictors find_response
+#' @importFrom insight find_formula get_predictors find_response check_if_installed
 eta_squared_posterior.stanreg <- function(model,
                                           partial = TRUE,
                                           generalized = FALSE,
@@ -27,32 +27,27 @@ eta_squared_posterior.stanreg <- function(model,
                                           draws = 500,
                                           verbose = TRUE,
                                           ...) {
-  check_if_installed("rstantools")
+  insight::check_if_installed("rstantools")
 
-  mo_inf <- insight::model_info(model)
-  if ((!mo_inf$is_linear) ||
-    mo_inf$is_multivariate) {
+  mi <- .get_model_info(model, ...)
+  if (!mi$is_linear || mi$is_multivariate) {
     stop("Computation of Eta Squared is only applicable to univariate linear models.")
   }
 
-  if (partial && mo_inf$is_mixed) {
+  if (partial && mi$is_mixed) {
     if (verbose) {
-      warning(
-        "Bayesian Partial Eta Squared not supported for mixed models.\n",
-        "Returning Eta Squared instead."
-      )
+      warning("Bayesian Partial Eta Squared not supported for mixed models.\n",
+              "Returning Eta Squared instead.")
     }
     partial <- FALSE
     # would need to account for random effects if present.
     # Too hard right now.
   }
 
-  if ((isTRUE(generalized) || is.character(generalized)) && mo_inf$is_mixed) {
+  if ((isTRUE(generalized) || is.character(generalized)) && mi$is_mixed) {
     if (verbose) {
-      warning(
-        "Bayesian Generalized Eta Squared not supported for mixed models.\n",
-        "Returning Eta Squared instead."
-      )
+      warning("Bayesian Generalized Eta Squared not supported for mixed models.\n",
+              "Returning Eta Squared instead.")
     }
     generalized <- FALSE
   }
@@ -63,13 +58,13 @@ eta_squared_posterior.stanreg <- function(model,
   resp_name <- insight::find_response(model)
 
   # test centered predictors
-  if (verbose) .all_centered(X)
+  # if (verbose) .all_centered(X)
 
   ## 2. get ppd
   ppd <- rstantools::posterior_predict(model,
     draws = draws, # for rstanreg
-    nsamples = draws
-  ) # for brms
+    nsamples = draws # for brms
+  )
 
   ## 3. Compute effect size...
   if (verbose) {
@@ -84,8 +79,13 @@ eta_squared_posterior.stanreg <- function(model,
     temp_fit <- stats::lm(f, temp_dat)
 
     # compute effect size
-    ANOVA <- ss_function(temp_fit, ...)
-    es <- eta_squared(ANOVA, ci = NULL, partial = partial, generalized = generalized)
+    if (isTRUE(verbose)) {
+      ANOVA <- ss_function(temp_fit, ...)
+    } else {
+      ANOVA <- suppressWarnings(ss_function(temp_fit, ...))
+    }
+
+    es <- eta_squared(ANOVA, ci = NULL, partial = partial, generalized = generalized, verbose = verbose)
 
     es <- stats::setNames(
       es[[if (partial) "Eta2_partial" else "Eta2"]],
@@ -104,46 +104,46 @@ eta_squared_posterior.stanreg <- function(model,
 eta_squared_posterior.brmsfit <- eta_squared_posterior.stanreg
 
 
-#' @keywords internal
-#' @importFrom stats contrasts
-.all_centered <- function(X) {
-  numeric <- sapply(X, inherits, what = c("numeric", "integer"))
-  numerics <- colnames(X)[numeric]
-  factors <- colnames(X)[!numeric]
-
-  numerics_centered <- factors_centered <- logical(0)
-
-  if (length(numerics)) {
-    numerics_centered <- sapply(
-      X[, numerics, drop = FALSE],
-      function(xi) isTRUE(all.equal(mean(xi), 0))
-    )
-  }
-
-
-  of <- options()$contrasts
-  if (length(factors)) {
-    factors_centered <- sapply(X[, factors, drop = FALSE], function(xi) {
-      # if a contrast has negative and positive values, it is assumed to be one of:
-      # "contr.sum", "contr.helmert", "contr.poly", "contr.bayes"
-      (is.factor(xi) && (any(contrasts(xi) < 0) & any(contrasts(xi) > 0))) ||
-        # Or if it is not a factor, is the default method one of these?
-        (!is.factor(xi) && all(of %in% c("contr.sum", "contr.poly", "contr.bayes", "contr.helmert")))
-    })
-  }
-
-
-  if ((length(numerics_centered) && !all(numerics_centered)) ||
-    length(factors_centered) && !all(factors_centered)) {
-    non_centered <- !c(numerics_centered, factors_centered)
-    non_centered <- names(non_centered)[non_centered]
-    warning(
-      "Not all variables are centered:\n ",
-      paste(non_centered, collapse = ", "),
-      "\n Results might be bogus if involved in interactions...",
-      call. = FALSE, immediate. = TRUE
-    )
-  }
-
-  return(invisible(NULL))
-}
+#' #' @keywords internal
+#' #' @importFrom stats contrasts
+#' .all_centered <- function(X) {
+#'   numeric <- sapply(X, inherits, what = c("numeric", "integer"))
+#'   numerics <- colnames(X)[numeric]
+#'   factors <- colnames(X)[!numeric]
+#'
+#'   numerics_centered <- factors_centered <- logical(0)
+#'
+#'   if (length(numerics)) {
+#'     numerics_centered <- sapply(
+#'       X[, numerics, drop = FALSE],
+#'       function(xi) isTRUE(all.equal(mean(xi), 0))
+#'     )
+#'   }
+#'
+#'
+#'   of <- options()$contrasts
+#'   if (length(factors)) {
+#'     factors_centered <- sapply(X[, factors, drop = FALSE], function(xi) {
+#'       # if a contrast has negative and positive values, it is assumed to be one of:
+#'       # "contr.sum", "contr.helmert", "contr.poly", "contr.bayes"
+#'       (is.factor(xi) && (any(contrasts(xi) < 0) & any(contrasts(xi) > 0))) ||
+#'         # Or if it is not a factor, is the default method one of these?
+#'         (!is.factor(xi) && all(of %in% c("contr.sum", "contr.poly", "contr.bayes", "contr.helmert")))
+#'     })
+#'   }
+#'
+#'
+#'   if ((length(numerics_centered) && !all(numerics_centered)) ||
+#'     length(factors_centered) && !all(factors_centered)) {
+#'     non_centered <- !c(numerics_centered, factors_centered)
+#'     non_centered <- names(non_centered)[non_centered]
+#'     warning(
+#'       "Not all variables are centered:\n ",
+#'       paste(non_centered, collapse = ", "),
+#'       "\n Results might be bogus if involved in interactions...",
+#'       call. = FALSE
+#'     )
+#'   }
+#'
+#'   return(invisible(NULL))
+#' }
