@@ -60,8 +60,8 @@
 #'
 #' ## Ties
 #' When tied values occur, they are each given the average of the ranks that
-#' would have been given had no ties occurred. No other corrections have been
-#' implemented yet.
+#' would have been given had no ties occurred. This results in an effect size of
+#' reduced magnitude. A correction has been applied for Kendall's *W*.
 #'
 #' # Confidence Intervals
 #' Confidence intervals for the rank-biserial correlation (and Cliff's *delta*)
@@ -85,13 +85,14 @@
 #' # =========================
 #'
 #' # Two Independent Samples ----------
-#' rank_biserial(mpg ~ am, data = mtcars)
+#' (rb <- rank_biserial(mpg ~ am, data = mtcars))
 #' # Same as:
 #' # rank_biserial("mpg", "am", data = mtcars)
 #' # rank_biserial(mtcars$mpg[mtcars$am=="0"], mtcars$mpg[mtcars$am=="1"])
 #'
 #' # More options:
 #' rank_biserial(mpg ~ am, data = mtcars, mu = -5)
+#' print(rb, append_CLES = TRUE)
 #'
 #'
 #' # One Sample ----------
@@ -104,13 +105,13 @@
 #' # Paired Samples ----------
 #' dat <- data.frame(Cond1 = c(1.83, 0.5, 1.62, 2.48, 1.68, 1.88, 1.55, 3.06, 1.3),
 #'                   Cond2 = c(0.878, 0.647, 0.598, 2.05, 1.06, 1.29, 1.06, 3.14, 1.29))
-#' (rbs <- rank_biserial(Pair(Cond1, Cond2) ~ 1, data = dat, paired = TRUE))
+#' (rb <- rank_biserial(Pair(Cond1, Cond2) ~ 1, data = dat, paired = TRUE))
 #'
 #' # same as:
 #' # rank_biserial(dat$Cond1, dat$Cond2, paired = TRUE)
 #'
 #' interpret_rank_biserial(0.78)
-#' interpret(rbs, rules = "funder2019")
+#' interpret(rb, rules = "funder2019")
 #'
 #'
 #' # Rank Epsilon Squared
@@ -171,12 +172,7 @@ rank_biserial <- function(x,
     if (!grepl("Wilcoxon", x$method)) {
       stop("'x' is not a Wilcoxon-test!", call. = FALSE)
     }
-    cl <- match.call()
-    return(effectsize(
-      x, ci = cl$ci,
-      mu = cl$mu, alternative = cl$alternative,
-      verbose = verbose
-    ))
+    return(effectsize(x, verbose = verbose, type = "rb"))
   }
 
   if (!missing(iterations) && verbose) {
@@ -187,7 +183,7 @@ rank_biserial <- function(x,
   }
 
   ## Prep data
-  out <- .deal_with_cohens_d_arguments(x, y, data)
+  out <- .get_data_2_samples(x, y, data, verbose, ...)
   x <- out$x
   y <- out$y
 
@@ -214,7 +210,6 @@ rank_biserial <- function(x,
   if (is.numeric(ci)) {
     # if (requireNamespace("boot", quietly = TRUE)) {
     #   out <- cbind(out, .rbs_ci_boot(
-    #     x,
     #     y,
     #     mu = mu,
     #     paired = paired,
@@ -240,7 +235,7 @@ rank_biserial <- function(x,
       nd <- sum((x - mu) != 0)
       maxw <- (nd^2 + nd) / 2
 
-      # From: https://en.wikipedia.org/wiki/Wilcoxon_signed-rank_test#Historical_T_statistic
+      # From: https://en.wikipedia.org/wiki/Wilcoxon_signed-rank_test#Historical_T_statistic/
       # wSE <- sqrt((n * (n + 1) * (2 * n + 1)) / 24)
       # Delta method for f(x) = w * 2 / (maxw) - 1
       # r_rbsSE <- wSE * sqrt(4 / (maxw)^2)
@@ -253,7 +248,7 @@ rank_biserial <- function(x,
       n1 <- length(x)
       n2 <- length(y)
 
-      # From: https://en.wikipedia.org/wiki/Mann%E2%80%93Whitney_U_test#Normal_approximation_and_tie_correction
+      # From: https://en.wikipedia.org/wiki/Mann%E2%80%93Whitney_U_test#Normal_approximation_and_tie_correction/
       # wSE <- sqrt((n1 * n2 * (n1 + n2 + 1)) / 12)
       # Delta method for f(x) = 1 - 2 * w / (n1 * n2) * sign(diff)
       # r_rbsSE <- wSE * sqrt(4 / (n1 * n2)^2)
@@ -331,7 +326,7 @@ rank_epsilon_squared <- function(x,
   }
 
   ## pep data
-  data <- .rank_anova_xg(x, groups, data)
+  data <- .get_data_multi_group(x, groups, data, ...)
   data <- stats::na.omit(data)
 
   ## compute
@@ -380,7 +375,7 @@ kendalls_w <- function(x,
   }
 
   ## prep data
-  data <- .kendalls_w_data(x, groups, blocks, data)
+  data <- .get_data_nested_groups(x, groups, blocks, data, ...)
   data <- stats::na.omit(data)
 
   ## compute
@@ -409,7 +404,7 @@ kendalls_w <- function(x,
 
 # rank_eta_squared <- function(x, g, data = NULL, ci = 0.95, iterations = 200) {
 #
-#   data <- .rank_anova_xg(x, g, data)
+#   data <- .get_data_multi_group(x, g, data)
 #   data <- stats::na.omit(data)
 #   x <- data$x
 #   g <- data$g
@@ -485,13 +480,25 @@ kendalls_w <- function(x,
   rankings <- apply(data, 1, .safe_ranktransform, verbose = verbose)
   rankings <- t(rankings) # keep dims
 
-  # TODO add ties correction?
   n <- ncol(rankings) # items
   m <- nrow(rankings) # judges
-
   R <- colSums(rankings)
-  S <- var(R) * (n - 1)
-  W <- (12 * S) / (m^2 * (n^3 - n))
+
+  if (!all(has_tie <- apply(rankings, 1, function(x) length(x) == insight::n_unique(x)))) {
+    # there are ties
+    have_ties <- rankings[!has_tie, , drop = FALSE]
+    Ti <- apply(have_ties, 1, function(r) {
+      ti <- apply(outer(unique(r), r, FUN = "=="), 1, sum)
+      sum(ti^3 - ti)
+    })
+
+    W <- (12 * sum(R^2) - 3 * (m^2) * n * ((n + 1)^2)) /
+      ((m^2) * n * (n^2 - 1) - m * sum(Ti))
+  } else {
+    S <- var(R) * (n - 1)
+    W <- (12 * S) / (m^2 * (n^3 - n))
+  }
+  W
 }
 
 ## CI ----
@@ -540,6 +547,7 @@ kendalls_w <- function(x,
 #   out
 # }
 
+#' @importFrom utils tail
 #' @keywords internal
 .repsilon_ci <- function(data, ci, alternative, iterations) {
   stopifnot(length(ci) == 1, ci < 1, ci > 0)
@@ -570,6 +578,7 @@ kendalls_w <- function(x,
   )
 }
 
+#' @importFrom utils tail
 #' @keywords internal
 .kendalls_w_ci <- function(data, ci, alternative, iterations) {
   stopifnot(length(ci) == 1, ci < 1, ci > 0)
@@ -595,98 +604,13 @@ kendalls_w <- function(x,
   )
 }
 
-## data ----
-
-
-#' @keywords internal
-#' @importFrom stats model.frame
-.rank_anova_xg <- function(x, groups, data) {
-  if (inherits(frm <- x, "formula")) {
-    mf <- stats::model.frame(formula = frm, data = data)
-
-    if (length(frm) != 3 | ncol(mf) != 2) {
-      stop("Formula must have the form of 'outcome ~ group'.", call. = FALSE)
-    }
-
-    x <- mf[[1]]
-    groups <- factor(mf[[2]])
-  } else if (inherits(x, "list")) {
-    groups <- rep(seq_along(x), sapply(x, length))
-    x <- unsplit(x, groups)
-  } else if (is.character(x)) {
-    x <- data[[x]]
-    groups <- data[[groups]]
-  } else if (length(x) != length(groups)) {
-    stop("x and g must be of the same length.", call. = FALSE)
-  }
-
-  data.frame(x, groups)
-}
-
-#' @keywords internal
-#' @importFrom stats model.frame reshape
-.kendalls_w_data <- function(x, groups, blocks, data = NULL) {
-  if (inherits(frm <- x, "formula")) {
-    if ((length(frm) != 3L) ||
-      (length(frm[[3L]]) != 3L) ||
-      (frm[[3L]][[1L]] != as.name("|"))) {
-      stop("Formula must have the 'x ~ groups | blocks'.", call. = FALSE)
-    }
-
-    frm[[3L]][[1L]] <- as.name("+")
-
-    mf <- stats::model.frame(formula = frm, data = data)
-
-    if (ncol(mf) != 3) {
-      stop("Formula must have only two terms on the RHS.", call. = FALSE)
-    }
-
-    x <- mf[[1]]
-    groups <- mf[[2]]
-    blocks <- mf[[3]]
-  } else if (inherits(x, c("table", "matrix", "array", "data.frame"))) {
-    data <- data.frame(
-      x = c(x),
-      groups = rep(factor(seq_len(ncol(x))),
-        each = nrow(x)
-      ),
-      blocks = rep(
-        factor(seq_len(nrow(x))),
-        ncol(x)
-      )
-    )
-
-    x <- data[[1]]
-    groups <- data[[2]]
-    blocks <- data[[3]]
-  } else if (is.character(x)) {
-    x <- data[[x]]
-    groups <- data[[groups]]
-    blocks <- data[[blocks]]
-  } else if (length(x) != length(groups) || length(x) != length(blocks)) {
-    stop("x, groups and blocks must be of the same length.", call. = FALSE)
-  }
-
-  data <- data.frame(x, groups, blocks, stringsAsFactors = FALSE)
-
-  data <- stats::reshape(
-    data,
-    direction = "wide",
-    v.names = "x",
-    timevar = "groups",
-    idvar = "blocks"
-  )
-
-  as.matrix(data[, -1])
-}
-
 
 # Utils -------------------------------------------------------------------
 
 .safe_ranktransform <- function(x, verbose = TRUE, ...) {
-  if (length(unique(x)) == 1) {
+  if (insight::n_unique(x) == 1) {
     if (verbose) warning("Only one unique value - rank fixed at 1")
     return(rep(1, length(x)))
   }
-  datawizard::ranktransform(x, verbose = verbose, ...)
+  datawizard::ranktransform(x, method = "average", ..., verbose = FALSE)
 }
