@@ -2,19 +2,25 @@ if (require("testthat") && require("effectsize")) {
 
   # anova() -----------------------------------------------------------------
   test_that("anova()", {
-    m <- structure(
-      c(3, 1, 1),
-      .Dim = c(1L, 3L),
-      .Dimnames = list("Term", c("F value", "NumDF", "DenDF")),
-      class = "anova"
-    )
+    # Make minimal ANOVA table
+    mod <- anova(lm(mpg ~ cyl + hp, mtcars))
 
-    expect_error(eta_squared(m), regexp = NA)
+    mod1 <- mod
+    mod1$DenDF <- mod1$Df[nrow(mod1)]
+    mod1 <- mod1[-nrow(mod1),]
+
+    expect_error(eta_squared(mod1), regexp = NA)
     expect_equal(
-      eta_squared(m)[, -1],
-      F_to_eta2(3, 1, 1),
+      eta_squared(mod1)[, -1],
+      F_to_eta2(mod1[["F value"]], mod1$Df, mod1$DenDF),
       ignore_attr = TRUE
     )
+    expect_warning(eta_squared(mod1, partial = FALSE))
+    expect_warning(eta_squared(mod1, generalized = TRUE))
+
+    mod2 <- mod1
+    mod2$`F value` <- NULL
+    expect_error(eta_squared(mod2))
   })
 
   # aov ---------------------------------------------------------------------
@@ -81,10 +87,14 @@ if (require("testthat") && require("effectsize")) {
     expect_message(eta_squared(aov(mpg ~ factor(gear) + am, mtcars)), regexp = NA)
 
     #### Alternative
-    m <- aov(mpg ~ factor(gear) + am, mtcars)
+    m <<- aov(mpg ~ factor(gear) + am, mtcars)
     et1 <- eta_squared(m)
     et2 <- eta_squared(m, ci = 0.9, alternative = "two.sided")
     expect_equal(et1$CI_low, et2$CI_low)
+
+    ### parameters:
+    expect_equal(eta_squared(parameters::model_parameters(m)),
+                 eta_squared(m))
   })
 
 
@@ -94,16 +104,30 @@ if (require("testthat") && require("effectsize")) {
     df <- iris
     df$Sepal.Big <- ifelse(df$Sepal.Width >= 3, "Yes", "No")
 
-    model <- aov(Sepal.Length ~ Sepal.Big + Error(Species), data = df)
+    model <<- aov(Sepal.Length ~ Sepal.Big + Error(Species), data = df)
 
     res <- eta_squared(model, partial = TRUE)
     expect_true(all(c("Group", "Parameter") %in% colnames(res)))
+    expect_equal(res$Eta2_partial, c(0.4472423, 0.1217329), tolerance = 0.001)
+    expect_equal(eta_squared(model, partial = FALSE)$Eta2,
+                 c(0.27671136, 0.04641607), tolerance = 0.001)
+
     res <- omega_squared(model, partial = TRUE)
     expect_true(all(c("Group", "Parameter") %in% colnames(res)))
+    expect_equal(res$Omega2_partial, c(-0.06795358, 0.04141846), tolerance = 0.001)
+    expect_equal(omega_squared(model, partial = FALSE)$Omega2,
+                 c(-0.04864626, 0.03287821), tolerance = 0.001)
+
     res <- epsilon_squared(model, partial = TRUE)
     expect_true(all(c("Group", "Parameter") %in% colnames(res)))
+    expect_equal(res$Epsilon2_partial, c(-0.1055154, 0.1157174), tolerance = 0.001)
+    expect_equal(epsilon_squared(model, partial = FALSE)$Epsilon2,
+                 c(-0.06528301, 0.04412238), tolerance = 0.001)
 
 
+    expect_equal(eta_squared(parameters::model_parameters(model)),
+                 eta_squared(model))
+
 
     skip_if_not_installed("afex")
     # non-partial Eta2 should be the same for aov and aovlist
@@ -123,8 +147,8 @@ if (require("testthat") && require("effectsize")) {
       )
     )
 
-    a1 <- eta_squared(model2, partial = F)
-    a2 <- eta_squared(model$aov, partial = F)
+    a1 <- eta_squared(model2, partial = FALSE)
+    a2 <- eta_squared(model$aov, partial = FALSE)
 
     rownames(a1) <- a1$Parameter
     rownames(a2) <- a2$Parameter
@@ -291,7 +315,7 @@ if (require("testthat") && require("effectsize")) {
     )
 
 
-    ef <- omega_squared(m, partial = TRUE)
+    ef <- omega_squared(m, partial = TRUE, alternative = "two")
     expect_equal(ef$Omega2_partial,
       c(0.3115, 0.1814, 0.2221, 0.2637, 0.1512, -0.0173, -0.0171),
       tolerance = 0.01
@@ -300,83 +324,10 @@ if (require("testthat") && require("effectsize")) {
       c(0, 0, 0, 0, 0, 0, 0),
       tolerance = 0.01
     )
-    # TODO Why are we getting diferent results on different systems and R releases?
-    # expect_equal(ef$CI_high,
-    #              c(0.5814, 0.5036, 0.5052, 0.4589, 0.3023, 0, 0),
-    #              tolerance = 0.01)
-  })
 
-
-
-  # afex --------------------------------------------------------------------
-  test_that("afex | within-mixed", {
-    skip_if_not_installed("afex")
-
-    data(obk.long, package = "afex")
-
-    mod <- afex::aov_ez("id", "value", obk.long,
-      between = c("treatment", "gender"),
-      within = c("phase", "hour"),
-      observed = "gender"
-    )
-
-    x <- eta_squared(mod, generalized = TRUE)
-    a <- anova(mod, observed = "gender")
-    expect_equal(a$ges, x$Eta2_generalized)
-
-    x <- eta_squared(mod)
-    a <- anova(mod, es = "pes")
-    expect_equal(a$pes, x$Eta2_partial)
-
-
-    x <- eta_squared(mod, include_intercept = TRUE)
-    a <- anova(mod, es = "pes", intercept = TRUE)
-    expect_equal(a$pes, x$Eta2_partial)
-
-    # see issue #389
-    data <- data.frame(subject = c(1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L,
-                                   2L, 1L, 2L, 1L, 2L, 1L, 2L),
-                       y = c(0.0586978983148275, -0.159870038198774, 0.0125690871484012,
-                             -0.0152529928817782, 0.092433880558952, 0.0359796249184537,
-                             -0.00786545388312909, 0.0340005375703463, 0.165294695432772,
-                             0.0201040753050847, 0.0741924965491503, -0.0345053066539826,
-                             0.0108194665250311, -0.163941830205729, 0.310344189786906,
-                             -0.106627229564326),
-                       A = c("A1", "A1", "A1", "A1", "A1", "A1", "A1", "A1", "A2",
-                             "A2", "A2", "A2", "A2", "A2", "A2", "A2"),
-                       B = c("B1", "B1", "B1", "B1", "B2", "B2", "B2", "B2", "B1",
-                             "B1", "B1", "B1", "B2", "B2", "B2", "B2"),
-                       C = c("C1", "C1", "C2", "C2", "C1", "C1", "C2", "C2", "C1",
-                             "C1", "C2", "C2", "C1", "C1", "C2", "C2"))
-    mod <- afex::aov_ez("subject", "y", data, within = c("A", "B", "C"))
-    tab <- as.data.frame(anova(mod, es = "pes"))
-    res <- eta_squared(mod)
-
-    tab <- tab[order(rownames(tab)),]
-    res <- res[order(res$Parameter),]
-
-    expect_equal(res$Eta2_partial,tab$pes, tolerance = 0.001)
-  })
-
-
-  # car ---------------------------------------------------------------------
-  test_that("car MLM", {
-    skip_if_not_installed("afex")
-    skip_if_not_installed("car")
-    data(obk.long, package = "afex")
-    model1 <- afex::aov_car(value ~ treatment * gender + Error(id / (phase * hour)),
-      data = obk.long, observed = "gender",
-      include_aov = FALSE
-    )
-
-    ws <- capture_warnings(eta_squared(model1$Anova, partial = FALSE))
-    expect_match(tail(ws, 1), "Currently only supports partial eta", fixed = TRUE)
-
-    expect_equal(
-      eta_squared(model1$Anova, verbose = FALSE)[1:3, ][[2]],
-      c(0.4407468, 0.2678884, 0.3635011),
-      tolerance = 0.01
-    )
+    expect_equal(ef$CI_high,
+                 c(0.626, 0.553, 0.557, 0.518, 0.355, 0, 0),
+                 tolerance = 0.01)
   })
 
 
@@ -465,11 +416,172 @@ if (require("testthat") && require("effectsize")) {
 
   # Special cases --------------------------------------------------------------
 
+  ## afex --------------------------------------------------------------------
+  test_that("afex | within-mixed", {
+    skip_if_not_installed("afex")
+
+    data(obk.long, package = "afex")
+
+    mod <- afex::aov_ez("id", "value", obk.long,
+                        between = c("treatment", "gender"),
+                        within = c("phase", "hour"),
+                        observed = "gender"
+    )
+
+    x <- eta_squared(mod, generalized = TRUE)
+    a <- anova(mod, observed = "gender")
+    expect_equal(a$ges, x$Eta2_generalized)
+
+    x <- eta_squared(mod)
+    a <- anova(mod, es = "pes")
+    expect_equal(a$pes, x$Eta2_partial)
+
+
+    x <- eta_squared(mod, include_intercept = TRUE)
+    a <- anova(mod, es = "pes", intercept = TRUE)
+    expect_equal(a$pes, x$Eta2_partial)
+
+    # see issue #389
+    data <- data.frame(subject = c(1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L,
+                                   2L, 1L, 2L, 1L, 2L, 1L, 2L),
+                       y = c(0.0586978983148275, -0.159870038198774, 0.0125690871484012,
+                             -0.0152529928817782, 0.092433880558952, 0.0359796249184537,
+                             -0.00786545388312909, 0.0340005375703463, 0.165294695432772,
+                             0.0201040753050847, 0.0741924965491503, -0.0345053066539826,
+                             0.0108194665250311, -0.163941830205729, 0.310344189786906,
+                             -0.106627229564326),
+                       A = c("A1", "A1", "A1", "A1", "A1", "A1", "A1", "A1", "A2",
+                             "A2", "A2", "A2", "A2", "A2", "A2", "A2"),
+                       B = c("B1", "B1", "B1", "B1", "B2", "B2", "B2", "B2", "B1",
+                             "B1", "B1", "B1", "B2", "B2", "B2", "B2"),
+                       C = c("C1", "C1", "C2", "C2", "C1", "C1", "C2", "C2", "C1",
+                             "C1", "C2", "C2", "C1", "C1", "C2", "C2"))
+    mod <- afex::aov_ez("subject", "y", data, within = c("A", "B", "C"))
+    tab <- as.data.frame(anova(mod, es = "pes"))
+    res <- eta_squared(mod)
+
+    tab <- tab[order(rownames(tab)),]
+    res <- res[order(res$Parameter),]
+
+    expect_equal(res$Eta2_partial,tab$pes, tolerance = 0.001)
+  })
+
+
+  test_that("afex | mixed()", {
+    skip_if_not_installed("afex")
+    skip_if_not_installed("lmerTest")
+
+    data(md_15.1, package = "afex")
+    # random intercept plus random slope
+    t15.4a <- afex::mixed(iq ~ timecat + (1 + time | id), data = md_15.1)
+    expect_equal(
+      eta_squared(t15.4a),
+      eta_squared(t15.4a$full_model)
+    )
+  })
+
+
+  ## car ---------------------------------------------------------------------
+  test_that("car MVM", {
+    skip_if_not_installed("afex")
+    skip_if_not_installed("car")
+
+    # Simple ---
+    ds <- data.frame(I = c(116, 96, 120, 110, 116, 126, 86, 80),
+                     II = c(76, 93, 112, 113, 75, 120, 90, 105),
+                     III = c(85, 63, 89, 60, 115, 101, 129, 67),
+                     IV = c(50, 87, 100, 60, 79, 70, 65, 65),
+                     id = 1:8)
+
+    ds_long <- data.frame(
+      id = c(1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L,
+             1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L,
+             1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L,
+             1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L),
+      ind_var = c("I", "I", "I", "I", "I", "I", "I", "I",
+                  "II", "II", "II", "II", "II", "II", "II", "II",
+                  "III", "III", "III", "III", "III", "III", "III", "III",
+                  "IV", "IV", "IV", "IV", "IV", "IV", "IV", "IV"),
+      score = c(116, 96, 120, 110, 116, 126, 86, 80,
+                76, 93, 112, 113, 75, 120, 90, 105,
+                85, 63, 89, 60, 115, 101, 129, 67,
+                50, 87, 100, 60, 79, 70, 65, 65)
+    )
+
+
+
+    fit <- lm(cbind(I, II, III, IV) ~ 1, data = ds)
+    in_rep <- data.frame(ind_var = gl(4, 1))
+    A_car <- car::Anova(fit, idata = in_rep, idesign =  ~ ind_var)
+
+    eta_car <- effectsize::eta_squared(A_car, ci = NULL)[[2]]
+
+    eta_afex <- afex::aov_ez('id', 'score', ds_long,
+                             within = 'ind_var',
+                             anova_table = list(es = "pes"))$anova_table$pes
+
+    expect_equal(eta_car, eta_afex)
+
+    # Complex ---
+    data(obk.long, package = "afex")
+
+    mod <- afex::aov_ez("id", "value", obk.long,
+                        between = c("treatment", "gender"),
+                        within = c("phase", "hour"),
+                        observed = "gender")
+    expect_equal(
+      sort(eta_squared(mod$Anova, generalized = "gender")[[2]]),
+      sort(mod$anova_table$ges)
+    )
+  })
+
+
+  test_that("Anova.mlm Manova", {
+    skip_if_not_installed("car")
+
+    data("mtcars")
+    mtcars$am_f <- factor(mtcars$am)
+    mtcars$cyl_f <- factor(mtcars$cyl)
+
+    mod <- lm(cbind(mpg, qsec) ~ am_f * cyl_f, data = mtcars)
+
+    Manova <- car::Manova(mod)
+
+    expect_true(is.null(summary(Manova, univariate = TRUE)[["univariate.tests"]]))
+    expect_error(eta_squared(Manova), regexp = NA)
+    expect_equal(
+      eta_squared(manova(mod))[[2]][2:3],
+      eta_squared(Manova)[[2]][2:3]
+    )
+
+  })
+
+  ## merMod --------------------
+
+  test_that("merMod and lmerModLmerTest", {
+    skip_if_not_installed("lmerTest")
+    skip_if_not_installed("lme4")
+
+    data("sleepstudy", package = "lme4")
+
+    m <- lme4::lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
+    mtest <- lmerTest::lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
+
+    t15.4a <- afex::mixed(iq ~ timecat + (1 + time | id), data = md_15.1)
+    expect_equal(
+      eta_squared(m),
+      eta_squared(mtest)
+    )
+  })
+
+
   ## tidymodels -------------------
   test_that("ets_squared | tidymodels", {
     skip_on_cran()
     skip_if_not_installed("tidymodels")
-    require("tidymodels", quietly = TRUE)
+    suppressPackageStartupMessages(require("tidymodels",
+                                           quietly = TRUE,
+                                           warn.conflicts = FALSE))
 
     set.seed(123)
     mod_lm <-
