@@ -45,8 +45,8 @@ if (require("testthat") && require("effectsize")) {
     E <- rank_epsilon_squared(x, g)
 
     expect_equal(E[[1]], 0.05934066, tolerance = 0.01)
-    expect_equal(E$CI_low, 0.004149302, tolerance = 0.01)
-    expect_equal(E$CI_high, 0.7596009, tolerance = 0.01)
+    expect_equal(E$CI_low, 0.01726463, tolerance = 0.01)
+    expect_equal(E$CI_high, 1)
 
     expect_equal(
       rank_epsilon_squared(x ~ g, ci = NULL),
@@ -58,27 +58,18 @@ if (require("testthat") && require("effectsize")) {
   test_that("kendalls_w", {
     skip_if_not_installed("boot")
     skip_if_not_installed("base", minimum_version = "3.6.0")
-    M1 <- structure(
-      c(5.4, 5.85, 5.2, 5.5, 5.7, 5.6, 5.55, 5.75, 5.5),
-      .Dim = c(3L, 3L),
-      .Dimnames = list(
-        c("1", "2", "3"),
-        c("Round Out", "Narrow Angle", "Wide Angle")
-      )
-    )
+    M1 <- cbind("Round Out" = c(5.4, 5.85, 5.2),
+                "Narrow Angle" = c(5.5, 5.7, 5.6),
+                "Wide Angle" = c(5.55, 5.75, 5.5))
 
-    M2 <- structure(
-      list(
-        id = c(1L, 1L, 1L, 2L, 2L, 2L, 3L, 3L, 3L),
-        name = c(
-          "Round Out", "Narrow Angle", "Wide Angle",
-          "Round Out", "Narrow Angle", "Wide Angle",
-          "Round Out", "Narrow Angle", "Wide Angle"
-        ),
-        value = c(5.4, 5.5, 5.55, 5.85, 5.7, 5.75, 5.2, 5.6, 5.5)
+    M2 <- data.frame(
+      id = c(1L, 1L, 1L, 2L, 2L, 2L, 3L, 3L, 3L),
+      name = c(
+        "Round Out", "Narrow Angle", "Wide Angle",
+        "Round Out", "Narrow Angle", "Wide Angle",
+        "Round Out", "Narrow Angle", "Wide Angle"
       ),
-      row.names = c(NA, -9L),
-      class = c("tbl_df", "tbl", "data.frame")
+      value = c(5.4, 5.5, 5.55, 5.85, 5.7, 5.75, 5.2, 5.6, 5.5)
     )
 
     set.seed(1)
@@ -93,5 +84,29 @@ if (require("testthat") && require("effectsize")) {
     expect_equal(W1[[1]], 0.11111111, tolerance = 0.01)
     expect_equal(W1$CI_low, 0.11111111, tolerance = 0.01)
     expect_equal(W1$CI_high, 1, tolerance = 0.01)
+
+    # Ties
+    dat <- data.frame(
+      pno = c(1L, 1L, 1L, 1L, 2L, 2L, 2L, 2L, 3L, 3L,
+              3L, 3L, 4L, 4L, 4L, 4L, 5L, 5L, 5L, 5L, 6L, 6L, 6L, 6L, 7L, 7L,
+              7L, 7L, 8L, 8L, 8L, 8L, 9L, 9L, 9L, 9L, 10L, 10L, 10L, 10L),
+      condition = c(1L, 1L, 2L, 2L, 1L, 1L, 2L, 2L, 1L,
+                    1L, 2L, 2L, 1L, 1L, 2L, 2L, 1L, 1L, 2L, 2L, 1L, 1L, 2L, 2L,
+                    1L, 1L, 2L, 2L, 1L, 1L, 2L, 2L, 1L, 1L, 2L, 2L, 1L, 1L, 2L,
+                    2L),
+      congruency = c(1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L,
+                     1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L,
+                     2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L,
+                     1L, 2L),
+      mrt = c(0.86, 0.86, 0.86, 0.78, 0.56, 0.56, 0.59, 0.66, 0.48,
+              0.5, 0.47, 0.51, 0.48, 0.52, 0.45, 0.47, 0.65, 0.79, 0.7,
+              0.81, 0.58, 0.6, 0.57, 0.6, 0.53, 0.61, 0.47, 0.49, 0.56,
+              0.64, 0.56, 0.6, 0.56, 0.66, 0.59, 0.63, 0.7, 0.92, 0.8,
+              0.96)
+    )
+    dat
+
+    W <- kendalls_w(mrt ~ interaction(condition, congruency) | pno, data = dat)
+    expect_equal(W[[1]], 0.4011, tolerance = 0.01)
   })
 }
