@@ -99,7 +99,7 @@ if (require("testthat") && require("effectsize")) {
   })
 
   test_that("hedges_g (and other bias correction things", {
-    expect_warning(x <- hedges_g(wt ~ am, data = mtcars, correction = TRUE))
+    x <- hedges_g(wt ~ am, data = mtcars)
     expect_equal(colnames(x)[1], "Hedges_g")
     expect_equal(x[[1]], 1.844, tolerance = 0.001)
     expect_equal(x$CI_low, 1.004, tolerance = 0.001)
@@ -150,4 +150,37 @@ if (require("testthat") && require("effectsize")) {
     expect_error(d <- cohens_d(y, f), regexp = NA)
     expect_true(attr(d, "pooled_sd"))
   })
+
+  test_that("CLES", {
+    set.seed(3)
+    x <<- rnorm(1000)
+    y <<- rnorm(500, mean = 0.2)
+
+    d <- cohens_d(x, y)
+    tt <- t.test(x,y, var.equal = TRUE)
+    expect_equal(CLES <- d_to_cles(d), cles(x, y))
+    expect_equal(cles(tt), CLES, ignore_attr = TRUE)
+    expect_error(cohens_u3(x, y), NA)
+    expect_error(p_overlap(x, y), NA)
+    expect_error(p_superiority(x, y), NA)
+
+    rb <- rank_biserial(x, y, ci = NULL)
+    w <- wilcox.test(x, y)
+    CLES <- cles(x, y, parametric = FALSE, ci = NULL)
+    expect_equal(rb_to_cles(rb), CLES[1,], ignore_attr = TRUE)
+    expect_equal(cles(w, parametric = FALSE)[,1:2], CLES, ignore_attr = TRUE)
+    expect_error(cohens_u3(x, y, parametric = FALSE), NA)
+    expect_error(p_overlap(x, y, parametric = FALSE), NA)
+    expect_error(p_superiority(x, y, parametric = FALSE), NA)
+
+    x <- 1:3
+    y <- c(1,1:3)
+    CLES <- cles(x, y)
+    # CV from https://rpsychologist.com/cohend/
+    expect_equal(CLES$Coefficient, c(0.5719, 0.6012, 0.8979), tolerance = 0.001)
+
+    # Should be close~
+    expect_equal(cles(x, y, parametric = FALSE, ci = NULL)$Coefficient[1],
+                 CLES$Coefficient[1], tolerance = 0.02)
+  })
 }
